package com.zanxiang.sdk.controller;

import com.zanxiang.common.domain.ResultVo;
import com.zanxiang.sdk.domain.params.*;
import com.zanxiang.sdk.domain.vo.UserLoginVO;
import com.zanxiang.sdk.service.IUserAuthService;
import com.zanxiang.sdk.service.IUserService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

/**
 * @author : lingfeng
 * @time : 2022-06-21
 * @description : 用户注册登录
 */
@Api(tags = "注册登录接口")
@CrossOrigin
@RestController
@RequestMapping(value = "/api/user")
public class UserLoginController {

    @Autowired
    private IUserAuthService userAuthService;

    @Autowired
    private IUserService userService;

    @ApiOperation(value = "用户普通注册")
    @PostMapping("/register/password")
    @ApiResponses(value = {@ApiResponse(code = 200, message = "成功", response = UserLoginVO.class)})
    public ResultVo<UserLoginVO> registerPassword(@Validated @RequestBody RegisterPasswordParam registerPasswordParam,
                                                  HttpServletRequest request) {
        return userService.registerPassword(registerPasswordParam, request);
    }

    @ApiOperation(value = "用户手机注册")
    @PostMapping("/register/mobile")
    @ApiResponses(value = {@ApiResponse(code = 200, message = "成功", response = UserLoginVO.class)})
    public ResultVo<UserLoginVO> registerMobile(@Validated @RequestBody RegisterMobileParam registerMobileParam,
                                                HttpServletRequest request) {
        return userService.registerMobile(registerMobileParam, request);
    }

    @ApiOperation(value = "用户名密码登录")
    @PostMapping("/login/password")
    @ApiResponses(value = {@ApiResponse(code = 200, message = "成功", response = UserLoginVO.class)})
    public ResultVo<UserLoginVO> loginPassword(@Validated @RequestBody LoginPasswordParam userLoginParam, HttpServletRequest request) {
        return userService.loginPassword(userLoginParam, request);
    }

    @ApiOperation(value = "用户手机号登录")
    @PostMapping("/login/mobile")
    @ApiResponses(value = {@ApiResponse(code = 200, message = "成功", response = UserLoginVO.class)})
    public ResultVo<UserLoginVO> loginMobile(@Validated @RequestBody LoginMobileParam loginMobileParam, HttpServletRequest request) {
        return userService.loginMobile(loginMobileParam, request);
    }

    @ApiOperation(value = "用户QQ授权登录")
    @GetMapping("/register/login/qq")
    @ApiResponses(value = {@ApiResponse(code = 200, message = "成功", response = UserLoginVO.class)})
    public ResultVo qqLoginAuth(HttpServletResponse response) {
        userAuthService.qqLoginAuth(response);
        return ResultVo.ok();
    }

    @ApiOperation(value = "用户QQ授权登录回调接口")
    @PostMapping("/register/login/qq/call/back")
    @ApiResponses(value = {@ApiResponse(code = 200, message = "成功", response = UserLoginVO.class)})
    public ResultVo<UserLoginVO> qqLoginCallback(@Validated @RequestBody QqLoginCallbackParam qqLoginCallbackParam, HttpServletRequest request) {
        return userAuthService.qqLoginCallback(qqLoginCallbackParam, request);
    }

    @ApiOperation(value = "用户微信授权登录")
    @GetMapping("/register/login/vx")
    @ApiResponses(value = {@ApiResponse(code = 200, message = "成功", response = UserLoginVO.class)})
    public ResultVo getUserDetail(HttpServletResponse response) {
        userAuthService.vxLoginAuth(response);
        return ResultVo.ok();
    }

    @ApiOperation(value = "用户微信授权登录回调接口")
    @PostMapping("/register/login/vx/call/back")
    @ApiResponses(value = {@ApiResponse(code = 200, message = "成功", response = UserLoginVO.class)})
    public ResultVo<UserLoginVO> vxLoginCallback(@Validated @RequestBody QqLoginCallbackParam qqLoginCallbackParam, HttpServletRequest request) {
        return userAuthService.vxLoginCallback(qqLoginCallbackParam, request);
    }
}
